@@ -12,12 +12,16 @@ TAKER_ACCOUNT_OWNER = '0xf809e07870dca762B9536d61A4fBEF1a17178092'
 CANONICAL_ORDERS_ADDRESS = '0xCd81398895bEa7AD9EFF273aeFFc41A9d83B4dAD'
 SOLO_MARGIN_ADDRESS = '0x1E0447b19BB6EcFdAe1e4AE1694b0C3659614e4e'
 PAYABLE_PROXY_ADDRESS = '0xa8b39829cE2246f89B31C013b8Cde15506Fb9A76'
-P1_ORDERS_ADDRESS = '0x3ea6F88eC8F7b24Bb3Ad206fa80124210e8e28F3'
-PERPETUAL_ADDRESS = '0x07aBe965500A49370D331eCD613c7AC47dD6e547'
 WETH_ADDRESS = '0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2'
 SAI_ADDRESS = '0x89d24A6b4CcB1B6fAA2625fE562bDD9a23260359'
 USDC_ADDRESS = '0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48'
 DAI_ADDRESS = '0x6B175474E89094C44Da98b954EedeAC495271d0F'
+WETH_PROXY_ADDRESS = '0x17ac4cC32696987CEa1737343188716b1D827E7B'
+BTC_P1_ORDERS_ADDRESS = '0x3ea6F88eC8F7b24Bb3Ad206fa80124210e8e28F3'
+BTC_PERPETUAL_ADDRESS = '0x07aBe965500A49370D331eCD613c7AC47dD6e547'
+ETH_P1_ORDERS_ADDRESS = '0x1d3ccceEE6d9f9c3b79ed5fAdD98E32B5d48b22E'
+ETH_PERPETUAL_ADDRESS = '0x09403FD14510F8196F7879eF514827CD76960B5d'
+CURRENCY_CONVERTER_PROXY_ADDRESS = '0xA0d885316Be23dE8bB19E7C53F6d483279E3467D'
 
 # ------------ Protocol Enums ------------
 ACTION_TYPE_DEPOSIT = 0
@@ -40,6 +44,7 @@ PAIR_WETH_DAI = 'WETH-DAI'
 PAIR_WETH_USDC = 'WETH-USDC'
 PAIR_DAI_USDC = 'DAI-USDC'
 PAIR_PBTC_USDC = 'PBTC-USDC'
+PAIR_WETH_PUSD = 'WETH-PUSD'
 
 DECIMALS_WETH = 18
 DECIMALS_SAI = 18
@@ -53,16 +58,7 @@ SIDE_SELL = 'SELL'
 
 # ------------ Fees ------------
 FROM_BIPS = Decimal('1e-4')
-SMALL_TRADE_SIZE_WETH = 20 * (10 ** DECIMALS_WETH)
-SMALL_TRADE_SIZE_DAI = 10000 * (10 ** DECIMALS_DAI)
-SMALL_TRADE_SIZE_PBTC = 0.5 * (10 ** DECIMALS_PBTC)
-FEE_SMALL_WETH = Decimal(100) * FROM_BIPS
-FEE_LARGE_WETH = Decimal(15) * FROM_BIPS
-FEE_SMALL_DAI = Decimal(100) * FROM_BIPS
-FEE_LARGE_DAI = Decimal(5) * FROM_BIPS
-FEE_LARGE_PBTC = Decimal(7.5) * FROM_BIPS
-FEE_SMALL_PBTC = Decimal(50) * FROM_BIPS
-FEE_MAKER_PBTC = Decimal(-2.5) * FROM_BIPS
+DEFAULT_LIMIT_FEE = Decimal(100) * FROM_BIPS
 FEE_ZERO = Decimal(0)
 
 # ------------ Transaction Constants ------------
